#!/usr/bin/env python
# -*- coding: utf-8 -*-

qnetman_home="/home/user/.qnetman/"

qnetman_path = "/opt/qnetman/"

file_db = qnetman_home + "qnetman.db"

file_setting = qnetman_home + "qnetman.conf"

i18n_rus = qnetman_path + "i18n/qnetman_rus.qm"

